==> deb-installer_24.12.tar.xz: BUILD/translations/deb-installer_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="118"/>
        <source>Install</source>
        <translation>Asenna</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="90"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Seuraavat paketit asennetaan. Paina &quot;Näytä tiedot...&quot; ja saat tietoa paketeista.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="98"/>
        <source>File: %1</source>
        <translation>Tiedosto: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="115"/>
        <source>Will install the following:</source>
        <translation>Asennetaan seuraavat:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="130"/>
        <source>Installing selected package please authenticate</source>
        <translation>Asenna valittu paketti, ole hyvä ja vahvista</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="135"/>
        <source>Press any key to close</source>
        <translation>Paina mitä tahansa näppäintä sulkeaksesi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Ohjelma Debian pakettien (deb-tiedostojen) asentamiseen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>tiedostot...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Asennettavien .deb-tiedostojen nimet</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[tiedosto...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Valitse asennettavat .deb-tiedostot</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb-tiedostot (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Ei .deb-tiedostoja toimitettu.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Tiedostoa %1 ei löydy</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Tiedosto %1 ei ole .deb-tiedosto.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Sinun täytyy suorittaa tämä ohjelma tavallisena käyttäjänä.</translation>
    </message>
</context>
</TS>

==> deb-installer_25.4.01.tar.xz: BUILD/translations/deb-installer_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Installer</name>
    <message>
        <location filename="../installer.cpp" line="82"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="85"/>
        <location filename="../installer.cpp" line="112"/>
        <source>Install</source>
        <translation>Asenna</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="91"/>
        <source>The following packages will be installed. Click &apos;Show Details...&apos; for information about the packages.</source>
        <translation>Seuraavat paketit asennetaan. Paina &quot;Näytä tiedot...&quot; ja saat tietoa paketeista.</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="96"/>
        <source>File: %1</source>
        <translation>Tiedosto: %1</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="110"/>
        <source>Will install the following:</source>
        <translation>Asennetaan seuraavat:</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="123"/>
        <source>Installing selected package, please authenticate</source>
        <translation>Asenna valittu paketti, ole hyvä ja vahvista</translation>
    </message>
    <message>
        <location filename="../installer.cpp" line="128"/>
        <source>Press any key to close</source>
        <translation>Paina mitä tahansa näppäintä sulkeaksesi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Program for installing Debian binary packages (deb files)</source>
        <translation>Ohjelma Debian pakettien (deb-tiedostojen) asentamiseen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>files...</source>
        <translation>tiedostot...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Name of .deb files to install</source>
        <translation>Asennettavien .deb-tiedostojen nimet</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>[file...]</source>
        <translation>[tiedosto...]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Select .deb files to install</source>
        <translation>Valitse asennettavat .deb-tiedostot</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Deb Files (*.deb)</source>
        <translation>Deb-tiedostot (*.deb)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>No .deb files were provided.</source>
        <translation>Ei .deb-tiedostoja toimitettu.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>File %1 not found</source>
        <translation>Tiedostoa %1 ei löydy</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>File %1 is not a .deb file.</source>
        <translation>Tiedosto %1 ei ole .deb-tiedosto.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as normal user.</source>
        <translation>Sinun täytyy suorittaa tämä ohjelma tavallisena käyttäjänä.</translation>
    </message>
</context>
</TS>
